package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.SBidMapper;
import com.ruoyi.business.domain.SBid;
import com.ruoyi.business.service.ISBidService;
import com.ruoyi.common.core.text.Convert;

/**
 * 项目Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class SBidServiceImpl implements ISBidService 
{
    @Autowired
    private SBidMapper sBidMapper;

    /**
     * 查询项目
     * 
     * @param bidId 项目主键
     * @return 项目
     */
    @Override
    public SBid selectSBidByBidId(String bidId)
    {
        return sBidMapper.selectSBidByBidId(bidId);
    }

    /**
     * 查询项目列表
     * 
     * @param sBid 项目
     * @return 项目
     */
    @Override
    public List<SBid> selectSBidList(SBid sBid)
    {
        return sBidMapper.selectSBidList(sBid);
    }

    /**
     * 新增项目
     * 
     * @param sBid 项目
     * @return 结果
     */
    @Override
    public int insertSBid(SBid sBid)
    {
        sBid.setCreateTime(DateUtils.getNowDate());
        return sBidMapper.insertSBid(sBid);
    }

    /**
     * 修改项目
     * 
     * @param sBid 项目
     * @return 结果
     */
    @Override
    public int updateSBid(SBid sBid)
    {
        sBid.setUpdateTime(DateUtils.getNowDate());
        return sBidMapper.updateSBid(sBid);
    }

    /**
     * 批量删除项目
     * 
     * @param bidIds 需要删除的项目主键
     * @return 结果
     */
    @Override
    public int deleteSBidByBidIds(String bidIds)
    {
        return sBidMapper.deleteSBidByBidIds(Convert.toStrArray(bidIds));
    }

    /**
     * 删除项目信息
     * 
     * @param bidId 项目主键
     * @return 结果
     */
    @Override
    public int deleteSBidByBidId(String bidId)
    {
        return sBidMapper.deleteSBidByBidId(bidId);
    }
}
